@@ -25,6 +25,7 @@ import numpy as np
 import xarray as xr
 
 from satpy import CHUNK_SIZE
+from satpy.readers import open_file_or_filename
 from satpy.readers.file_handlers import BaseFileHandler
 from satpy.readers.utils import np2str
 
@@ -96,8 +97,9 @@ class NetCDF4FileHandler(BaseFileHandler):
             filename, filename_info, filetype_info)
         self.file_content = {}
         self.cached_file_content = {}
+        self._use_h5netcdf = False
         try:
-            file_handle = netCDF4.Dataset(self.filename, 'r')
+            file_handle = self._get_file_handle()
         except IOError:
             LOG.exception(
                 'Failed reading file %s. Possibly corrupted file', self.filename)
@@ -119,6 +121,9 @@ class NetCDF4FileHandler(BaseFileHandler):
         else:
             file_handle.close()
 
+    def _get_file_handle(self):
+        return netCDF4.Dataset(self.filename, 'r')
+
     @staticmethod
     def _set_file_handle_auto_maskandscale(file_handle, auto_maskandscale):
         if hasattr(file_handle, "set_auto_maskandscale"):
@@ -199,27 +204,33 @@ class NetCDF4FileHandler(BaseFileHandler):
     def _collect_global_attrs(self, obj):
         """Collect all the global attributes for the provided file object."""
         global_attrs = {}
-        for key in obj.ncattrs():
+        for key in self._get_object_attrs(obj):
             fc_key = f"/attr/{key}"
             value = self._get_attr_value(obj, key)
             self.file_content[fc_key] = global_attrs[key] = value
         self.file_content["/attrs"] = global_attrs
 
+    def _get_object_attrs(self, obj):
+        return obj.__dict__
+
     def _collect_attrs(self, name, obj):
         """Collect all the attributes for the provided file object."""
-        for key in obj.ncattrs():
+        for key in self._get_object_attrs(obj):
             fc_key = f"{name}/attr/{key}"
             value = self._get_attr_value(obj, key)
             self.file_content[fc_key] = value
 
     def _get_attr_value(self, obj, key):
-        value = getattr(obj, key)
+        value = self._get_attr(obj, key)
         try:
             value = np2str(value)
         except ValueError:
             pass
         return value
 
+    def _get_attr(self, obj, key):
+        return getattr(obj, key)
+
     def collect_dimensions(self, name, obj):
         """Collect dimensions."""
         for dim_name, dim_obj in obj.dimensions.items():
@@ -246,8 +257,14 @@ class NetCDF4FileHandler(BaseFileHandler):
         cache_vars = self._collect_cache_var_names(cache_var_size)
         for var_name in cache_vars:
             v = self.file_content[var_name]
-            self.cached_file_content[var_name] = xr.DataArray(
+            try:
+                arr = xr.DataArray(
                     v[:], dims=v.dimensions, attrs=v.__dict__, name=v.name)
+            except ValueError:
+                # Handle scalars for h5netcdf backend
+                arr = xr.DataArray(
+                    v.__array__(), dims=v.dimensions, attrs=v.__dict__, name=v.name)
+            self.cached_file_content[var_name] = arr
 
     def _collect_cache_var_names(self, cache_var_size):
         return [varname for (varname, var)
@@ -315,8 +332,9 @@ class NetCDF4FileHandler(BaseFileHandler):
         else:
             g = self.file_handle[group]
         v = g[key]
+        attrs = self._get_object_attrs(v)
         x = xr.DataArray(
-                da.from_array(v), dims=v.dimensions, attrs=v.__dict__,
+                da.from_array(v), dims=v.dimensions, attrs=attrs,
                 name=v.name)
         return x
 
@@ -337,9 +355,19 @@ class NetCDF4FileHandler(BaseFileHandler):
             return self.cached_file_content[var_name]
         v = self.file_content[var_name]
         if isinstance(v, xr.DataArray):
-            return v
-        self.cached_file_content[var_name] = xr.DataArray(
-            v[:], dims=v.dimensions, attrs=v.__dict__, name=v.name)
+            val = v
+        else:
+            try:
+                val = v[:]
+                val = xr.DataArray(val, dims=v.dimensions, attrs=self._get_object_attrs(v), name=v.name)
+            except IndexError:
+                # Handle scalars
+                val = v.__array__().item()
+                val = xr.DataArray(val, dims=(), attrs={}, name=var_name)
+            except AttributeError:
+                # Handle strings
+                val = v
+        self.cached_file_content[var_name] = val
         return self.cached_file_content[var_name]
 
 
@@ -349,3 +377,56 @@ def _compose_replacement_names(variable_name_replacements, var, variable_names):
         for val in vals:
             if key in var:
                 variable_names.append(var.format(**{key: val}))
+
+
+class NetCDF4FsspecFileHandler(NetCDF4FileHandler):
+    """NetCDF4 file handler using fsspec to read files remotely."""
+
+    def _get_file_handle(self):
+        try:
+            # Default to using NetCDF4 backend for local files
+            return super()._get_file_handle()
+        except OSError:
+            # The netCDF4 lib raises either FileNotFoundError or OSError for remote files. OSError catches both.
+            import h5netcdf
+            f_obj = open_file_or_filename(self.filename)
+            self._use_h5netcdf = True
+            return h5netcdf.File(f_obj, 'r')
+
+    def __getitem__(self, key):
+        """Get item for given key."""
+        if self._use_h5netcdf:
+            return self._getitem_h5netcdf(key)
+        return super().__getitem__(key)
+
+    def _getitem_h5netcdf(self, key):
+        from h5netcdf import Group, Variable
+        val = self.file_content[key]
+        if isinstance(val, Variable):
+            return self._get_variable(key, val)
+        if isinstance(val, Group):
+            return self._get_group(key, val)
+        return val
+
+    def _collect_cache_var_names(self, cache_var_size):
+        if self._use_h5netcdf:
+            return self._collect_cache_var_names_h5netcdf(cache_var_size)
+        return super()._collect_cache_var_names(cache_var_size)
+
+    def _collect_cache_var_names_h5netcdf(self, cache_var_size):
+        from h5netcdf import Variable
+        return [varname for (varname, var)
+                in self.file_content.items()
+                if isinstance(var, Variable)
+                and isinstance(var.dtype, np.dtype)  # vlen may be str
+                and np.prod(var.shape) * var.dtype.itemsize < cache_var_size]
+
+    def _get_object_attrs(self, obj):
+        if self._use_h5netcdf:
+            return obj.attrs
+        return super()._get_object_attrs(obj)
+
+    def _get_attr(self, obj, key):
+        if self._use_h5netcdf:
+            return obj.attrs[key]
+        return super()._get_attr(obj, key)
