@@ -31,8 +31,13 @@ import pytest
 
 import satpy
 from satpy import DatasetDict
+from satpy._config import cached_entry_points
 from satpy.composites.config_loader import load_compositor_configs_for_sensors
 
+# NOTE:
+# The following fixtures are not defined in this file, but are used and injected by Pytest:
+# - tmp_path
+
 
 class TestBuiltinAreas(unittest.TestCase):
     """Test that the builtin areas are all valid."""
@@ -292,6 +297,10 @@ def _create_yamlbased_plugin(
 class TestPluginsConfigs:
     """Test that plugins are working."""
 
+    def setup_method(self):
+        """Set up the test."""
+        cached_entry_points.cache_clear()
+
     def test_get_plugin_configs(self, fake_composite_plugin_etc_path):
         """Check that the plugin configs are looked for."""
         from satpy._config import get_entry_points_config_dirs
@@ -480,6 +489,26 @@ class TestConfigObject:
         with satpy.config.set(config_path='/single/string/paths/are/bad'):
             pytest.raises(ValueError, satpy._config.get_config_path_safe)
 
+    def test_tmp_dir_is_writable(self):
+        """Check that the default temporary directory is writable."""
+        import satpy
+        assert _is_writable(satpy.config["tmp_dir"])
+
+
+def test_is_writable():
+    """Test writable directory check."""
+    assert _is_writable(os.getcwd())
+    assert not _is_writable("/foo/bar")
+
+
+def _is_writable(directory):
+    import tempfile
+    try:
+        with tempfile.TemporaryFile(dir=directory):
+            return True
+    except OSError:
+        return False
+
 
 def _os_specific_multipaths():
     exp_paths = ['/my/configs1', '/my/configs2', '/my/configs3']
